@@ -1,7 +1,6 @@
 
-import os
 from os import path
-from shutil import rmtree, copytree
+from shutil import copytree
 
 import rvirtualenv
 
